# HG changeset patch
# User Boris Grozev <boris@jitsi.org>
# Date 1591039653 18000
#      Mon Jun 01 14:27:33 2020 -0500
# Node ID 2df11e00f7ed5db0e680433cd3754a9f77cf837b
# Parent  9c27b2385fadfdf38909bfcfc25621e2f64550fb
Supports regular expressions in trusted_proxies

diff -r 9c27b2385fad -r 2df11e00f7ed plugins/mod_http.lua
--- a/plugins/mod_http.lua	Mon Jun 01 17:55:01 2020 +0200
+++ b/plugins/mod_http.lua	Mon Jun 01 14:27:33 2020 -0500
@@ -202,8 +202,27 @@
 
 module.add_host(module); -- set up handling on global context too
 
+-- Each entry is either a literal that has to match exacty, or a regular expression used to match against
+-- the string representation of an IP address (if it starts with "re:"). For example, the 10.0.0.0/8 network
+-- can be matched with "re:10%..*".
 local trusted_proxies = module:get_option_set("trusted_proxies", { "127.0.0.1", "::1" })._items;
 
+local function is_trusted_proxy(ip)
+	for trusted_proxy in trusted_proxies do
+		local match = false;
+		if trusted_proxy:sub(1, #"re:") == "re:" then
+			match = ip:match("^"..(trusted_proxy:sub(#"re:"+1).."$"))
+        else
+			match = ip == trusted_proxy
+		end
+
+		if match then
+			return true
+		end
+    end
+	return false
+end
+
 local function get_ip_from_request(request)
 	local ip = request.conn:ip();
 	local forwarded_for = request.headers.x_forwarded_for;
@@ -218,7 +237,7 @@
 		-- Case d) If all IPs are in trusted proxies, something went obviously wrong and the logic never overwrites `ip`, leaving it at the original request IP.
 		forwarded_for = forwarded_for..", "..ip;
 		for forwarded_ip in forwarded_for:gmatch("[^%s,]+") do
-			if not trusted_proxies[forwarded_ip] then
+			if not is_trusted_proxy(forwarded_ip) then
 				ip = forwarded_ip;
 			end
 		end
